@@ -110,7 +110,10 @@ class Dumper(DumperBase):
         # There is no cdb api for the size of bitfields.
         # Workaround this issue by parsing the native debugger text for integral types.
         if val.type.code == TypeCode.Integral:
-            integerString = nativeValue.nativeDebuggerValue()
+            try:
+                integerString = nativeValue.nativeDebuggerValue()
+            except UnicodeDecodeError:
+                integerString = ''  # cannot decode - read raw
             if integerString == 'true':
                 val.ldata = int(1).to_bytes(1, byteorder='little')
             elif integerString == 'false':
@@ -514,7 +517,10 @@ class Dumper(DumperBase):
         raise Exception("cdb does not support calling functions")
 
     def nameForCoreId(self, id):
-        idName = cdbext.call('Cored4!Core::nameForId(%d)' % id)
+        for dll in ['Utilsd4', 'Utils4']:
+            idName = cdbext.call('%s!Utils::nameForId(%d)' % (dll, id))
+            if idName is not None:
+                break
         return self.fromNativeValue(idName)
 
     def putCallItem(self, name, rettype, value, func, *args):
